@@ -44,6 +44,7 @@ import re
 import threading
 import urllib.parse
 import warnings
+from dataclasses import dataclass
 from datetime import date, datetime, time, timedelta, timezone, tzinfo
 from decimal import Decimal
 from time import sleep
@@ -290,16 +291,17 @@ def get_roles_values(headers, header):
     ]
 
 
-class TrinoStatus(object):
-    def __init__(self, id, stats, warnings, info_uri, next_uri, update_type, rows, columns=None):
-        self.id = id
-        self.stats = stats
-        self.warnings = warnings
-        self.info_uri = info_uri
-        self.next_uri = next_uri
-        self.update_type = update_type
-        self.rows = rows
-        self.columns = columns
+@dataclass
+class TrinoStatus:
+    id: str
+    stats: Dict[str, str]
+    warnings: List[Any]
+    info_uri: str
+    next_uri: Optional[str]
+    update_type: Optional[str]
+    update_count: Optional[int]
+    rows: List[Any]
+    columns: List[Any]
 
     def __repr__(self):
         return (
@@ -665,6 +667,7 @@ class TrinoRequest(object):
             info_uri=response["infoUri"],
             next_uri=self._next_uri,
             update_type=response.get("updateType"),
+            update_count=response.get("updateCount"),
             rows=response.get("data", []),
             columns=response.get("columns"),
         )
@@ -729,11 +732,10 @@ class TrinoQuery(object):
     def __init__(
             self,
             request: TrinoRequest,
-            sql: str,
+            query: str,
             legacy_primitive_types: bool = False,
     ) -> None:
-        self.query_id: Optional[str] = None
-
+        self._query_id: Optional[str] = None
         self._stats: Dict[Any, Any] = {}
         self._info_uri: Optional[str] = None
         self._warnings: List[Dict[Any, Any]] = []
@@ -742,11 +744,21 @@ class TrinoQuery(object):
         self._cancelled = False
         self._request = request
         self._update_type = None
-        self._sql = sql
+        self._update_count = None
+        self._next_uri = None
+        self._query = query
         self._result: Optional[TrinoResult] = None
         self._legacy_primitive_types = legacy_primitive_types
         self._row_mapper: Optional[RowMapper] = None
 
+    @property
+    def query_id(self) -> Optional[str]:
+        return self._query_id
+
+    @property
+    def query(self) -> Optional[str]:
+        return self._query
+
     @property
     def columns(self):
         if self.query_id:
@@ -764,6 +776,10 @@ class TrinoQuery(object):
     def update_type(self):
         return self._update_type
 
+    @property
+    def update_count(self):
+        return self._update_count
+
     @property
     def warnings(self):
         return self._warnings
@@ -787,10 +803,10 @@ class TrinoQuery(object):
         if self.cancelled:
             raise exceptions.TrinoUserError("Query has been cancelled", self.query_id)
 
-        response = self._request.post(self._sql, additional_http_headers)
+        response = self._request.post(self._query, additional_http_headers)
         status = self._request.process(response)
         self._info_uri = status.info_uri
-        self.query_id = status.id
+        self._query_id = status.id
         self._stats.update({"queryId": self.query_id})
         self._update_state(status)
         self._warnings = getattr(status, "warnings", [])
@@ -808,6 +824,8 @@ class TrinoQuery(object):
     def _update_state(self, status):
         self._stats.update(status.stats)
         self._update_type = status.update_type
+        self._update_count = status.update_count
+        self._next_uri = status.next_uri
         if not self._row_mapper and status.columns:
             self._row_mapper = RowMapperFactory().create(columns=status.columns,
                                                          legacy_primitive_types=self._legacy_primitive_types)
@@ -830,12 +848,11 @@ class TrinoQuery(object):
 
     def cancel(self) -> None:
         """Cancel the current query"""
-        if self.query_id is None or self.finished:
+        if self._next_uri is None:
             return
 
-        url = self._request.get_url("/v1/query/{}".format(self.query_id))
         logger.debug("cancelling query: %s", self.query_id)
-        response = self._request.delete(url)
+        response = self._request.delete(self._next_uri)
         logger.debug(response)
         if response.status_code == requests.codes.no_content:
             self._cancelled = True
