@@ -23,6 +23,7 @@ import math
 import uuid
 from decimal import Decimal
 from typing import Any, Dict, List, NamedTuple, Optional  # NOQA for mypy types
+from urllib.parse import urlparse
 
 import trino.client
 import trino.exceptions
@@ -92,7 +93,7 @@ class Connection(object):
 
     def __init__(
         self,
-        host,
+        host: str,
         port=constants.DEFAULT_PORT,
         user=None,
         source=constants.DEFAULT_SOURCE,
@@ -114,8 +115,11 @@ class Connection(object):
         roles=None,
         timezone=None,
     ):
-        self.host = host
-        self.port = port
+        # Automatically assign http_schema, port based on hostname
+        parsed_host = urlparse(host, allow_fragments=False)
+
+        self.host = host if parsed_host.hostname is None else parsed_host.hostname + parsed_host.path
+        self.port = port if parsed_host.port is None else parsed_host.port
         self.user = user
         self.source = source
         self.catalog = catalog
@@ -141,7 +145,7 @@ class Connection(object):
         else:
             self._http_session = http_session
         self.http_headers = http_headers
-        self.http_scheme = http_scheme
+        self.http_scheme = http_scheme if not parsed_host.scheme else parsed_host.scheme
         self.auth = auth
         self.extra_credential = extra_credential
         self.redirect_handler = redirect_handler
@@ -315,13 +319,20 @@ class Cursor(object):
 
     @property
     def rowcount(self):
-        """Not supported.
+        """The rowcount will be returned for INSERT, UPDATE, DELETE, MERGE
+        and CTAS statements based on `update_count` returned by the Trino
+        API.
 
-        Trino cannot reliablity determine the number of rows returned by an
-        operation. For example, the result of a SELECT query is streamed and
-        the number of rows is only knowns when all rows have been retrieved.
+        If the rowcount can't be determined, -1 will be returned.
+
+        Trino cannot reliably determine the number of rows returned for DQL
+        queries. For example, the result of a SELECT query is streamed and
+        the number of rows is only known when all rows have been retrieved.
+
+        See https://peps.python.org/pep-0249/#rowcount
         """
-
+        if self._query is not None and self._query.update_count is not None:
+            return self._query.update_count
         return -1
 
     @property
@@ -336,6 +347,12 @@ class Cursor(object):
             return self._query.query_id
         return None
 
+    @property
+    def query(self) -> Optional[str]:
+        if self._query is not None:
+            return self._query.query
+        return None
+
     @property
     def warnings(self):
         if self._query is not None:
@@ -357,7 +374,7 @@ class Cursor(object):
         :param name: name that will be assigned to the prepared statement.
         """
         sql = f"PREPARE {name} FROM {statement}"
-        query = trino.client.TrinoQuery(self.connection._create_request(), sql=sql,
+        query = trino.client.TrinoQuery(self.connection._create_request(), query=sql,
                                         legacy_primitive_types=self._legacy_primitive_types)
         query.execute()
 
@@ -367,7 +384,7 @@ class Cursor(object):
         params
     ):
         sql = 'EXECUTE ' + statement_name + ' USING ' + ','.join(map(self._format_prepared_param, params))
-        return trino.client.TrinoQuery(self._request, sql=sql, legacy_primitive_types=self._legacy_primitive_types)
+        return trino.client.TrinoQuery(self._request, query=sql, legacy_primitive_types=self._legacy_primitive_types)
 
     def _format_prepared_param(self, param):
         """
@@ -447,7 +464,7 @@ class Cursor(object):
 
     def _deallocate_prepared_statement(self, statement_name: str) -> None:
         sql = 'DEALLOCATE PREPARE ' + statement_name
-        query = trino.client.TrinoQuery(self.connection._create_request(), sql=sql,
+        query = trino.client.TrinoQuery(self.connection._create_request(), query=sql,
                                         legacy_primitive_types=self._legacy_primitive_types)
         query.execute()
 
@@ -479,7 +496,7 @@ class Cursor(object):
                 self._deallocate_prepared_statement(statement_name)
 
         else:
-            self._query = trino.client.TrinoQuery(self._request, sql=operation,
+            self._query = trino.client.TrinoQuery(self._request, query=operation,
                                                   legacy_primitive_types=self._legacy_primitive_types)
             self._iterator = iter(self._query.execute())
         return self
@@ -575,7 +592,7 @@ class Cursor(object):
             sql = f"DESCRIBE OUTPUT {statement_name}"
             self._query = trino.client.TrinoQuery(
                 self._request,
-                sql=sql,
+                query=sql,
                 legacy_primitive_types=self._legacy_primitive_types,
             )
             result = self._query.execute()
